==> qtjambi-qt3drender-debuginfo-macos-5.15.18.jar: sources/QtJambi3DRender/QPickEvent_shell.h <==
#ifndef QPICKEVENT_SHELL_H
#define QPICKEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <Qt3DRender/qpickevent.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qentity.h>
#include <Qt3DRender/qviewport.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qvector3d.h>
#include <QtJambi/RegistryAPI>


class QPickEvent_shell : public Qt3DRender::QPickEvent, public QtJambiShellInterface
{
public:
    QPickEvent_shell();
    QPickEvent_shell(const QPointF& position0, const QVector3D& worldIntersection1, const QVector3D& localIntersection2, float distance3);
    QPickEvent_shell(const QPointF& position0, const QVector3D& worldIntersection1, const QVector3D& localIntersection2, float distance3, Qt3DRender::QPickEvent::Buttons button4, int buttons5, int modifiers6);
    ~QPickEvent_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPickEvent_access : public Qt3DRender::QPickEvent
{
};

#endif // QPICKEVENT_SHELL_H

==> qtjambi-qt3drender-debuginfo-macos-6.6.1.jar: sources/QtJambi3DRender/QPickEvent_shell.h <==
#ifndef QPICKEVENT_SHELL_H
#define QPICKEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <Qt3DRender/qpickevent.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qentity.h>
#include <Qt3DRender/qviewport.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qvectornd.h>
#include <QtJambi/RegistryAPI>


class QPickEvent_shell : public Qt3DRender::QPickEvent, public QtJambiShellInterface
{
public:
    QPickEvent_shell();
    QPickEvent_shell(const QPointF& position0, const QVector3D& worldIntersection1, const QVector3D& localIntersection2, float distance3);
    QPickEvent_shell(const QPointF& position0, const QVector3D& worldIntersection1, const QVector3D& localIntersection2, float distance3, Qt3DRender::QPickEvent::Buttons button4, int buttons5, int modifiers6);
    ~QPickEvent_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPickEvent_access : public Qt3DRender::QPickEvent
{
};

#endif // QPICKEVENT_SHELL_H
